==> dcl_0.9.2.orig.tar.gz: dcl/inc/class.boConfig.inc.php <==
<?php
/*
 * $Id: class.boConfig.inc.php,v 1.4.2.5.2.2 2003/01/26 19:07:15 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

LoadStringResource('bo');

class boConfig
{
	function modify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.htmlConfig');
		$obj->Show();
	}

	function dbmodify()
	{
		global $oConfig, $dcl_info, $HTTP_POST_VARS;

		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$aCheckboxes = array('DCL_AUTO_DATE', 'DCL_PROJECT_XML_TEMPLATES', 'DCL_SMTP_ENABLED',
							'DCL_GATEWAY_TICKET_ENABLED', 'DCL_GATEWAY_TICKET_AUTORESPOND',
							'DCL_GATEWAY_TICKET_REPLY', 'DCL_PROJECT_INCLUDE_CHILD_STATS',
							'DCL_PROJECT_INCLUDE_PARENT_STATS', 'DCL_PROJECT_BROWSE_PARENTS_ONLY',
							'DCL_WO_NOTIFICATION_HTML', 'DCL_TCK_NOTIFICATION_HTML'
						);

		$sql = 'SELECT dcl_config_name, dcl_config_field, dcl_config_int,';
		$sql .= 'dcl_config_double, dcl_config_date, dcl_config_datetime,';
		$sql .= 'dcl_config_varchar FROM dcl_config WHERE dcl_config_name!=\'DCL_VERSION\'';

		// get all of the settings except for DCL_VERSION and update
		// the ones that have changed.
		$oConfig->Query($sql);
		while ($oConfig->next_record())
		{
			$oConfig->GetRow();
			if (IsSet($HTTP_POST_VARS[$oConfig->dcl_config_name]))
				$HTTP_POST_VARS[$oConfig->dcl_config_name] = $oConfig->GPCStripSlashes($HTTP_POST_VARS[$oConfig->dcl_config_name]);
				
			// checkboxes need special handling
			if (in_array($oConfig->dcl_config_name, $aCheckboxes))
			{
				$newVal = IsSet($HTTP_POST_VARS[$oConfig->dcl_config_name]) && $HTTP_POST_VARS[$oConfig->dcl_config_name] == 'Y' ? 'Y' : 'N';
				if ($newVal != $dcl_info[$oConfig->dcl_config_name])
				{
					eval('$oConfig->' . $oConfig->dcl_config_field . ' = $newVal;');
					$oConfigTemp = $oConfig;
					$oConfigTemp->Edit();
					$dcl_info[$oConfig->dcl_config_name] = $newVal;
				}
			}
			elseif ($dcl_info[$oConfig->dcl_config_name] != $HTTP_POST_VARS[$oConfig->dcl_config_name])
			{
				eval('$oConfig->' . $oConfig->dcl_config_field . ' = $HTTP_POST_VARS[\'' . $oConfig->dcl_config_name . '\'];');
				$oConfigTemp = $oConfig;
				$oConfigTemp->Edit();
				$dcl_info[$oConfig->dcl_config_name] = $HTTP_POST_VARS[$oConfig->dcl_config_name];
			}
		}

		$obj = CreateObject('dcl.htmlAdminMain');
		$obj->Show();
	}
}
?>

==> dcl_0.9.4.4.orig.tar.gz: dcl/inc/class.boConfig.inc.php <==
<?php
/*
 * $Id: class.boConfig.inc.php,v 1.4.2.5.2.9 2004/01/02 00:45:34 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

LoadStringResource('bo');

class boConfig
{
	function modify()
	{
		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$obj = CreateObject('dcl.htmlConfig');
		$obj->Show();
	}

	function dbmodify()
	{
		global $dcl_info, $HTTP_POST_VARS;

		commonHeader();
		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$aCheckboxes = array('DCL_AUTO_DATE', 'DCL_PROJECT_XML_TEMPLATES', 'DCL_SMTP_ENABLED',
							'DCL_GATEWAY_TICKET_ENABLED', 'DCL_GATEWAY_TICKET_AUTORESPOND',
							'DCL_GATEWAY_TICKET_REPLY', 'DCL_PROJECT_INCLUDE_CHILD_STATS',
							'DCL_PROJECT_INCLUDE_PARENT_STATS', 'DCL_PROJECT_BROWSE_PARENTS_ONLY',
							'DCL_WO_NOTIFICATION_HTML', 'DCL_TCK_NOTIFICATION_HTML',
							'DCL_GATEWAY_WO_ENABLED', 'DCL_GATEWAY_WO_AUTORESPOND',
							'DCL_GATEWAY_WO_REPLY', 'DCL_WO_SECONDARY_ACCOUNTS_ENABLED',
							'DCL_WIKI_ENABLED', 'DCL_SCCS_ENABLED'
						);

		// get all of the settings except for DCL_VERSION and LAST_CONFIG_UPDATE and update
		// the ones that have changed.
		$bHasUpdates = false;
		$oConfig = CreateObject('dcl.dbConfig');
		$oConfig->Connect();
		$oConfig->LoadForModify();
		while ($oConfig->next_record())
		{
			$oConfig->GetRow();
			if (IsSet($HTTP_POST_VARS[$oConfig->dcl_config_name]))
				$HTTP_POST_VARS[$oConfig->dcl_config_name] = $oConfig->GPCStripSlashes($HTTP_POST_VARS[$oConfig->dcl_config_name]);

			// checkboxes need special handling
			if (in_array($oConfig->dcl_config_name, $aCheckboxes))
			{
				$newVal = IsSet($HTTP_POST_VARS[$oConfig->dcl_config_name]) && $HTTP_POST_VARS[$oConfig->dcl_config_name] == 'Y' ? 'Y' : 'N';
				if ($newVal != $dcl_info[$oConfig->dcl_config_name])
				{
					eval('$oConfig->' . $oConfig->dcl_config_field . ' = $newVal;');
					$oConfigTemp = $oConfig;
					$oConfigTemp->Edit();
					$dcl_info[$oConfig->dcl_config_name] = $newVal;
					$bHasUpdates = true;
				}
			}
			elseif ($dcl_info[$oConfig->dcl_config_name] != $HTTP_POST_VARS[$oConfig->dcl_config_name])
			{
				eval('$oConfig->' . $oConfig->dcl_config_field . ' = $HTTP_POST_VARS[\'' . $oConfig->dcl_config_name . '\'];');
				$oConfigTemp = $oConfig;
				$oConfigTemp->Edit();
				$dcl_info[$oConfig->dcl_config_name] = $HTTP_POST_VARS[$oConfig->dcl_config_name];
				$bHasUpdates = true;
			}
		}

		if ($bHasUpdates)
			$oConfigTemp->UpdateTimeStamp();

		$obj = CreateObject('dcl.htmlAdminMain');
		$obj->Show();
	}
}
?>
